@@ -1,8 +1,8 @@
-/*  $Id: french-conjugator.cpp,v 1.7 2004/02/26 03:12:41 sarrazip Exp $
+/*  $Id: french-conjugator.cpp,v 1.9 2005/03/13 04:03:26 sarrazip Exp $
     french-conjugator.cpp - Conjugation of French verbs
 
     verbiste - French conjugation system
-    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -48,7 +48,8 @@ static struct option knownOptions[] =
     { "version",        no_argument,            NULL, 'v' },
     { "mode",           required_argument,      NULL, 'm' },
     { "tense",          required_argument,      NULL, 't' },
-    { "template",       required_argument,      NULL, 'p' },
+    { "template",       required_argument,      NULL, 'l' },
+    { "pronouns",       no_argument,            NULL, 'p' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -63,7 +64,9 @@ public:
       : Command(),
 	reqMode(INVALID_MODE),
 	reqTense(INVALID_TENSE),
-	reqTemplate()
+	reqTemplate(),
+	includePronouns(false),
+	aspirateH(false)
     {
     }
 
@@ -75,6 +78,7 @@ public:
     Mode reqMode;
     Tense reqTense;
     string reqTemplate;
+    bool includePronouns;
 
 protected:
 
@@ -82,6 +86,8 @@ protected:
 
 private:
 
+    bool aspirateH;
+
     void displayTense(FrenchVerbDictionary &fvd,
 			const string &radical,
 			const TemplateSpec &templ,
@@ -115,7 +121,8 @@ ConjugatorCommand::displayTense(FrenchVerbDictionary &fvd,
     typedef vector<VS> VVS;
 
     VVS conjug;
-    FrenchVerbDictionary::generateTense(radical, templ, mode, tense, conjug);
+    FrenchVerbDictionary::generateTense(radical, templ, mode, tense, conjug,
+					includePronouns, aspirateH);
 
     for (VVS::const_iterator p = conjug.begin(); p != conjug.end(); p++)
     {
@@ -138,6 +145,8 @@ ConjugatorCommand::displayConjugation(FrenchVerbDictionary &fvd,
 {
     try
     {
+	aspirateH = fvd.isVerbStartingWithAspirateH(infinitive);
+
 	string radical = FrenchVerbDictionary::getRadical(infinitive, tname);
 
 	displayTense(fvd, radical, templ, INFINITIVE_MODE, PRESENT_TENSE);
@@ -208,7 +217,7 @@ displayHelp()
 
     cout <<
 "\n"
-"Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>\n"
+"Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>\n"
 "This program is free software; you may redistribute it under the terms of\n"
 "the GNU General Public License.  This program has absolutely no warranty.\n"
     ;
@@ -221,6 +230,7 @@ displayHelp()
 "--mode=M           Only display mode M (infinitive, indicative, etc)\n"
 "--tense=T          Only display tense T (present, past, etc)\n"
 "--template=T       Use template T to conjugate the verbs\n"
+"--pronouns         Include pronouns in the displayed conjugation\n"
 "\n"
 "See the " << commandName << "(1) manual page for details.\n"
 "\n"
@@ -231,7 +241,10 @@ displayHelp()
 int
 main(int argc, char *argv[])
 {
-    ConjugatorCommand cmd;
+    Mode reqMode = INVALID_MODE;
+    Tense reqTense = INVALID_TENSE;
+    string reqTemplate;
+    bool includePronouns = false;
 
     #ifdef HAVE_GETOPT_LONG
 
@@ -240,7 +253,7 @@ main(int argc, char *argv[])
     int c;
     try { do
     {
-	c = getopt_long(argc, argv, "", knownOptions, NULL);
+	c = getopt_long(argc, argv, "hvm:t:l:p", knownOptions, NULL);
 
 	switch (c)
 	{
@@ -248,8 +261,8 @@ main(int argc, char *argv[])
 		break;  // nothing to do
 
 	    case 'm':
-		cmd.reqMode = FrenchVerbDictionary::convertModeName(optarg);
-		if (cmd.reqMode == INVALID_MODE)
+		reqMode = FrenchVerbDictionary::convertModeName(optarg);
+		if (reqMode == INVALID_MODE)
 		{
 		    cerr << commandName << ": invalid mode " << optarg << "\n";
 		    return EXIT_FAILURE;
@@ -257,26 +270,21 @@ main(int argc, char *argv[])
 		break;
 
 	    case 't':
-		cmd.reqTense = FrenchVerbDictionary::convertTenseName(optarg);
-		if (cmd.reqTense == INVALID_TENSE)
+		reqTense = FrenchVerbDictionary::convertTenseName(optarg);
+		if (reqTense == INVALID_TENSE)
 		{
 		    cerr << commandName << ": invalid tense " << optarg << "\n";
 		    return EXIT_FAILURE;
 		}
 		break;
 
+	    case 'l':
+		reqTemplate = optarg;
+		break;
+
 	    case 'p':
-	    {
-		FrenchVerbDictionary &fvd = cmd.getFrenchVerbDictionary();
-		cmd.reqTemplate = optarg;
-		if (fvd.getTemplate(cmd.reqTemplate) == NULL)
-		{
-		    cerr << commandName << ": invalid conjugation template "
-							<< optarg << "\n";
-		    return EXIT_FAILURE;
-		}
+		includePronouns = true;
 		break;
-	    }
 
 	    case 'v':
 		displayVersionNo();
@@ -303,5 +311,19 @@ main(int argc, char *argv[])
 
     #endif  /* ndef HAVE_GETOPT_LONG */
 
+    ConjugatorCommand cmd;
+    cmd.reqMode = reqMode;
+    cmd.reqTense = reqTense;
+    cmd.reqTemplate = reqTemplate;
+    cmd.includePronouns = includePronouns;
+
+    if (!reqTemplate.empty() &&
+		cmd.getFrenchVerbDictionary().getTemplate(reqTemplate) == NULL)
+    {
+	cerr << commandName << ": invalid conjugation template "
+					    << optarg << "\n";
+	return EXIT_FAILURE;
+    }
+
     return cmd.run(argc - optind, argv + optind);
 }
