@@ -1,4 +1,4 @@
-/*  $Id: gnome-app.cpp,v 1.4 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: gnome-app.cpp,v 1.6 2005/04/24 18:17:08 sarrazip Exp $
     gtk-app.cpp - GTK+ application main function
 
     verbiste - French conjugation system
@@ -21,6 +21,7 @@
 */
 
 #include "main-window.h"
+#include "gui/conjugation.h"
 
 #include <libintl.h>
 #include <locale.h>
@@ -78,7 +79,8 @@ main(int argc, char *argv[])
     hideOnDelete = FALSE;
     try
     {
-	initVerbDict();
+	extern verbiste::FrenchVerbDictionary *fvd;
+	fvd = initVerbDict();
     }
     catch(logic_error &e)
     {
