@@ -1,4 +1,4 @@
-/*  $Id: main-window.h,v 1.7 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: main-window.h,v 1.8 2005/04/24 18:04:09 sarrazip Exp $
     main-window.h - Input and conjugation window
 
     verbiste - French conjugation system
@@ -36,6 +36,7 @@ extern gboolean hideOnDelete;
 void showAbout();
 
 
+#if 0
 /**
     Initialize the verb dictionary.
     @throws	std::logic_error	object representing a failure to
@@ -43,6 +44,7 @@ void showAbout();
 					its knowledge base
 */
 void initVerbDict() throw(std::logic_error);
+#endif
 
 
 /**
