@@ -1,4 +1,4 @@
-/*  $Id: panel-applet.cpp,v 1.9 2005/03/13 04:03:26 sarrazip Exp $
+/*  $Id: panel-applet.cpp,v 1.11 2005/04/24 18:17:08 sarrazip Exp $
     panel-applet.cpp - GNOME Panel applet main functions
 
     verbiste - French conjugation system
@@ -21,6 +21,7 @@
 */
 
 #include "main-window.h"
+#include "gui/conjugation.h"
 
 #include <panel-applet.h>
 
@@ -139,7 +140,8 @@ appletFill(PanelApplet *applet, const gchar *iid, gpointer)
 
     try
     {
-	initVerbDict();
+	extern verbiste::FrenchVerbDictionary *fvd;
+	fvd = initVerbDict();
     }
     catch(logic_error &e)
     {
