@@ -1,8 +1,8 @@
-/*  $Id: FrenchVerbDictionary.cpp,v 1.16 2004/03/23 22:35:56 sarrazip Exp $
+/*  $Id: FrenchVerbDictionary.cpp,v 1.18 2005/03/13 04:03:26 sarrazip Exp $
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
-    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2005 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -380,6 +380,10 @@ FrenchVerbDictionary::readVerbs(xmlDocPtr doc) throw(logic_error)
 
 	knownVerbs[infinitive] = tname;
 
+	// <aspirate-h>: If this verb starts with an aspirate h, remember it:
+	if (t->next != NULL && t->next->next != NULL)
+	    aspirateHVerbs.insert(infinitive);
+
 	// Insert the verb in the trie.
 	// A list of template names is associated to each verb in this trie.
 
@@ -740,16 +744,71 @@ FrenchVerbDictionary::generateTense(const string &radical,
 				const TemplateSpec &templ,
 				Mode mode,
 				Tense tense,
-				vector< vector<string> > &dest) throw()
+				vector< vector<string> > &dest,
+				bool includePronouns,
+				bool aspirateH) throw()
 {
     const ModeSpec &modeSpec = templ.find(mode)->second;
     const TenseSpec &tenseSpec = modeSpec.find(tense)->second;
 
+    if (mode != INDICATIVE_MODE
+	    && mode != CONDITIONAL_MODE
+	    && mode != SUBJUNCTIVE_MODE)
+	includePronouns = false;
+
     for (TenseSpec::const_iterator p = tenseSpec.begin();
 				    p != tenseSpec.end(); p++)
     {
 	dest.push_back(vector<string>());
 	for (PersonSpec::const_iterator i = p->begin(); i != p->end(); i++)
-	    dest.back().push_back(radical + *i);
+	{
+	    string pronoun;
+	    string v = radical + *i;
+
+	    if (includePronouns)
+	    {
+		size_t noPers = p - tenseSpec.begin();
+		switch (noPers)
+		{
+		    case 0:
+		    {
+			bool elideJe = false;
+			if (!aspirateH)
+			{
+			    char init = (v.empty() ? '\0' : v[0]);
+			    bool isVowelOrH = (strchr(
+				    "aeiouyhAEIOUYH",
+								init) != NULL);
+			    if (isVowelOrH)
+				elideJe = true;
+			}
+			pronoun = (elideJe ? "j'" : "je ");
+			break;
+		    }
+		    case 1: pronoun = "tu "; break;
+		    case 2: pronoun = "il "; break;
+		    case 3: pronoun = "nous "; break;
+		    case 4: pronoun = "vous "; break;
+		    case 5: pronoun = "ils "; break;
+		}
+
+		if (mode == SUBJUNCTIVE_MODE)
+		{
+		    if (noPers == 2 || noPers == 5)
+			pronoun = "qu'" + pronoun;
+		    else
+			pronoun = "que " + pronoun;
+		}
+	    }
+
+	    dest.back().push_back(pronoun + v);
+	}
     }
 }
+
+
+bool FrenchVerbDictionary::isVerbStartingWithAspirateH(
+				const std::string &infinitive) const throw()
+{
+    return aspirateHVerbs.find(infinitive) != aspirateHVerbs.end();
+}
